#
# spec file for package ghc-turtle
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name turtle
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.5.10
Release:        1.3
Summary:        Shell programming, Haskell-style
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-ansi-wl-pprint-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-clock-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-foldl-devel
BuildRequires:  ghc-hostname-devel
BuildRequires:  ghc-managed-devel
BuildRequires:  ghc-optional-args-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroups-devel
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-system-fileio-devel
BuildRequires:  ghc-system-filepath-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-compat-devel
BuildRequires:  ghc-unix-devel
%if %{with tests}
BuildRequires:  ghc-doctest-devel
%endif

%description
'turtle' is a reimplementation of the Unix command line environment in Haskell
so that you can use Haskell as both a shell and a scripting language.

Features include:

* Batteries included: Command an extended suite of predefined utilities

* Interoperability: You can still run external shell commands

* Portability: Works on Windows, OS X, and Linux

* Exception safety: Safely acquire and release resources

* Streaming: Transform or fold command output in constant space

* Patterns: Use typed regular expressions that can parse structured values

* Formatting: Type-safe 'printf'-style text formatting

* Modern: Supports 'text' and 'system-filepath'

Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
quick-start guide

'turtle' is designed to be beginner-friendly, but as a result lacks certain
features, like tracing commands. If you feel comfortable using 'turtle' then
you should also check out the 'Shelly' library which provides similar
functionality.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%changelog
* Mon Jul  9 2018 psimons@suse.com
- Update turtle to version 1.5.10.
  1.5.10
  * Increase upper bound on `doctest` and `criterion`
  1.5.9
  * Add `symlink`
* Mon Apr 23 2018 psimons@suse.com
- Update turtle to version 1.5.8.
  A more detailed change log is not available.
* Thu Apr 12 2018 psimons@suse.com
- Update turtle to version 1.5.7.
  A more detailed change log is not available.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jun 19 2017 psimons@suse.com
- Update to version 1.3.6.
* Thu Jun  8 2017 psimons@suse.com
- Update to version 1.3.5.
* Wed May 31 2017 psimons@suse.com
- Update to version 1.3.4.
* Wed May  3 2017 psimons@suse.com
- Update to version 1.3.3 with cabal2obs.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 1.3.2 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.3.1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.8 revision 0 with cabal2obs.
* Mon May 30 2016 mimi.vx@gmail.com
- update to 1.2.8
* Tue Apr 26 2016 mimi.vx@gmail.com
- update to 1.2.7
* Mon Apr  4 2016 mimi.vx@gmail.com
- update to 1.2.6
* Sun Jan 24 2016 mimi.vx@gmail.com
- initial commit
